@@ -1,5 +1,6 @@
 #' Visualization of the network meta-analysis using plate plot
 #' @import ggplot2
+#' @import ggtext
 #' @param nma_result the network meta-analysis results, which needs to be visualized
 #' @param null_value_zero a vector of indicators for upper diagonal matrix and lower diagonal matrix
 #'   null_value_zero = 1 (TRUE) means results are log odds ratio, risk difference, mean difference
@@ -11,7 +12,7 @@
 #'   lower_better = 0 (FALSE) means if RR < 1 results favors treatment j
 #'   Allowed values are c(upper diagonal matrix, lower diagonal matrix): c(0, 0), c(1, 0), c(0, 1), c(1, 1)
 #' @param design_method a vector of indicators for upper diagonal matrix and lower diagonal matrix
-#'   design_method = "cicle" means plate plot is drawn
+#'   design_method = "circle" means plate plot is drawn
 #'   design_method = "text" means text is displayed
 #'   Allowed values are c(upper diagonal matrix, lower diagonal matrix):
 #'   c("circle", "text"), c("circle", "circle"), c("text", "circle"), c("text", "text")
@@ -31,8 +32,6 @@
 #'   Allowed values are positive integers
 #' @param title the title of plot
 #'   Allowed values are strings
-#' @param bold make the text bold or not
-#'   Allowed values are TRUE or FALSE
 #' @param upper_diagonal_name the name of upper diagonal plot
 #'   Allowed values are strings
 #' @param lower_diagonal_name the name of lower diagonal plot
@@ -42,7 +41,11 @@
 #'   "#F0E2E6" (lowest) to "#E51D8E" (highest)
 #' @param offdiagonal_color the background colors to indicate difference between upper diagonal and lower diagonal
 #'   Allowed values are color names, e.g. c("khaki", "cornsilk") means the background colors for
-#'   upper diagonal cells and lower diagonal cells are "khaki" and "cornsilk" respectively
+#'   upper diagonal cells and lower diagonal cells are "khaki" and "cornsilk" respectively.
+#'   If you want to highlight the cells with p-value <= 0.05,
+#'   please use array of 3 colors for cells in upper diagonal with p-value <= 0.05,
+#'   cells in lower diagonal with p-value <= 0.05,
+#'   and other cells with p-value > 0.05 respectively: c("khaki", "cornsilk","white")
 #' @param text_and_circle_color the colors (low and high) to indicate plates
 #'   Allowed values are color names, e.g. c("red", "grey10", "blue", "grey70", "white"):
 #'   c("red", "grey10", "blue"), a vector of 3 colors for low, mid and high p-values;
@@ -68,7 +71,6 @@ plateplot <- function(nma_result,
                          plate_circle_samesize = FALSE,
                          transform_rc_ullr_boolean = TRUE,
                          text_size = 3.0,
-                         bold = FALSE,
                          max_substring = 4,
                          title = NA,
                          upper_diagonal_name = NA,
@@ -180,8 +182,11 @@ plateplot <- function(nma_result,
   if(!is.null(Results$Symbol_indicators)){
     Results$Symbol_indicators <- .reorder_matrix(Results$Symbol_indicators, Order_temp, 2, 2)
   }
+  if(!is.null(Results$Color)){
+    Results$Color <- .reorder_matrix(Results$Color, Order_temp, 2, 2)
+  }
 
-  ## Transform the dataset from row-column type to upperleft-lowerright type
+  ## Transform the data set from row-column type to upperleft-lowerright type
   if(transform_rc_ullr_boolean == 1){
     Results <- .from_rc_to_ullr(Results = Results, null_value_zero = null_value_zero_lDM)
   }
@@ -213,15 +218,47 @@ plateplot <- function(nma_result,
   ##### create data frames for off-diagonal matrix's background and name
   if(!is.na(upper_diagonal_name) | !is.na(lower_diagonal_name)){
     upperdiagonal_background <- data.frame(
-      id = rep(1, each = 2 * ntrt),
-      x = c(rep(c(1:ntrt), each = 2)),
-      y = c(ntrt, rep(c((ntrt-1):1), each = 2), ntrt)
+      id = c(rep(c(1:(ntrt*(ntrt-1)/2)), each = 4)),
+      x = rep(0, each = 2*(ntrt-1)*ntrt),
+      y = rep(0, each = 2*(ntrt-1)*ntrt),
+      color = offdiagonal_color[1]
     )
     lowerdiagonal_background <- data.frame(
-      id = rep(1, each = 2 * ntrt),
-      x = c(rep(c(0:(ntrt-1)), each = 2)),
-      y = c(0, rep(c((ntrt-1):1), each = 2), 0)
+      id = c(rep(c(1:(ntrt*(ntrt-1)/2)), each = 4)),
+      x = rep(0, each = 2*(ntrt-1)*ntrt),
+      y = rep(0, each = 2*(ntrt-1)*ntrt),
+      color = offdiagonal_color[2]
     )
+    # setup upper-diagonal background
+    for(j in 2:ntrt){
+      for(i in 1:(j-1)){
+        i_j = ((j-2)*(j-1)/2+i-1)*4
+        upperdiagonal_background[i_j+1, c("x", "y")] =  c(j-1, ntrt-(i-1))
+        upperdiagonal_background[i_j+2, c("x", "y")] =  c(j-1, ntrt-i)
+        upperdiagonal_background[i_j+3, c("x", "y")] =  c(j, ntrt-i)
+        upperdiagonal_background[i_j+4, c("x", "y")] =  c(j, ntrt-(i-1))
+        if(!is.null(Results$Color)){
+          upperdiagonal_background[(i_j+1):(i_j+4), "color"] = Results$Color[i, j]
+        }else{
+          upperdiagonal_background[(i_j+1):(i_j+4), "color"] = ifelse(is.na(offdiagonal_color[3]) | Results$Pvalues[i,j]<=0.05, offdiagonal_color[1], offdiagonal_color[3])
+        }
+      }
+    }
+    # setup lower-diagonal background
+    for(i in 2:ntrt){
+      for(j in 1:(i-1)){
+        i_j = ((i-2)*(i-1)/2+j-1)*4
+        lowerdiagonal_background[i_j+1, c("x", "y")] =  c(j-1, ntrt-(i-1))
+        lowerdiagonal_background[i_j+2, c("x", "y")] =  c(j-1, ntrt-i)
+        lowerdiagonal_background[i_j+3, c("x", "y")] =  c(j, ntrt-i)
+        lowerdiagonal_background[i_j+4, c("x", "y")] =  c(j, ntrt-(i-1))
+        if(!is.null(Results$Color)){
+          lowerdiagonal_background[(i_j+1):(i_j+4), "color"] = Results$Color[i, j]
+        }else{
+          lowerdiagonal_background[(i_j+1):(i_j+4), "color"] = ifelse(is.na(offdiagonal_color[3]) | Results$Pvalues[i,j]<=0.05, offdiagonal_color[2], offdiagonal_color[3])
+        }
+      }
+    }
   }
 
   ##### create data frames for diagonal triangles (upper and lower), and diagonal texts
@@ -665,7 +702,7 @@ plateplot <- function(nma_result,
                                    limits = c(0, 1), name="SUCRA(%)")+
       # include diagonal lines or not
       ggplot2::geom_segment(ggplot2::aes(x = x, y = y, xend = xend, yend = yend),
-                            color = "white", size = 1.5, data = border_lines_diagonal)+
+                            color = "white", linewidth = 1.5, data = border_lines_diagonal)+
       # diagonal_text_abbrv_size
       # diagonal_text_numbers_size
       ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = text), size = text_size*8/7, fontface = "bold", data = diagonal_text_abbr)+
@@ -673,7 +710,7 @@ plateplot <- function(nma_result,
       ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = values), size = text_size*6/7, fontface = "bold", data = diagonal_text_lower)
   }
 
-  ### draw the offdiagonal background and names
+  ### draw the off-diagonal background and names
   if(TRUE){
     diagonal_name_df <- data.frame(x = 0, y = ntrt + 0.25, label = "Treatment names")
     p <- p + ggplot2::geom_label(ggplot2::aes(x = x, y = y, label = label), colour = "black",
@@ -682,7 +719,7 @@ plateplot <- function(nma_result,
                                  data = diagonal_name_df)
   }
   if(!is.na(upper_diagonal_name)){
-    p <- p + ggplot2::geom_polygon(ggplot2::aes(x = x, y = y, group = id), fill = offdiagonal_color[1],
+    p <- p + ggplot2::geom_polygon(ggplot2::aes(x = x, y = y, group = id), fill = upperdiagonal_background$color,
                                    data = upperdiagonal_background)
     upperdiagonal_name_df <- data.frame(x = ntrt, y = ntrt + 0.25, label = upper_diagonal_name)
     p <- p + ggplot2::geom_label(ggplot2::aes(x = x, y = y, label = label), colour = "black",
@@ -691,7 +728,7 @@ plateplot <- function(nma_result,
                                  data = upperdiagonal_name_df)
   }
   if(!is.na(lower_diagonal_name)){
-    p <- p + ggplot2::geom_polygon(ggplot2::aes(x = x, y = y, group = id), fill = offdiagonal_color[2],
+    p <- p + ggplot2::geom_polygon(ggplot2::aes(x = x, y = y, group = id), fill = lowerdiagonal_background$color,
                                    data = lowerdiagonal_background)
     lowerdiagonal_name_df <- data.frame(x = 0, y = -0.25, label = lower_diagonal_name)
     p <- p + ggplot2::geom_label(ggplot2::aes(x = x, y = y, label = label), colour = "black",
@@ -709,16 +746,9 @@ plateplot <- function(nma_result,
                           colour = text_and_circle_color[5], data = lower_dm_plate3, na.rm = TRUE)
   }else if(design_method_lDM == "text"){
     p <- p+
-      ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = text, colour = color),
-                         size = text_size, data = lower_DM_text, parse = TRUE, na.rm = TRUE)
-    if(bold == TRUE){
-      p <- p+
-        ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = text, colour = color),
-                                size = text_size + text_size/140, data = lower_DM_text, parse = TRUE, na.rm = TRUE)+
-        ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = text, colour = color),
-                           size = text_size + text_size/70, data = lower_DM_text, parse = TRUE, na.rm = TRUE)
-    }
-
+      ggtext::geom_richtext(ggplot2::aes(x = x, y = y, label = text, colour = color),
+                         size = text_size, data = lower_DM_text, fill = NA, label.color = NA,
+                         label.padding = grid::unit(rep(0, 4), "pt"), na.rm = TRUE)
   }
 
   ### draw the upper diagonal matrix
@@ -731,16 +761,9 @@ plateplot <- function(nma_result,
                           colour = text_and_circle_color[5], data = upper_dm_plate3, na.rm = TRUE)
   }else if(design_method_uDM == "text"){
     p <- p+
-      ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = text, colour = color),
-                         size = text_size, data = upper_DM_text, parse = TRUE, na.rm = TRUE)
-    if(bold == TRUE){
-      p <- p+
-        ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = text, colour = color),
-                           size = text_size + text_size/140, data = upper_DM_text, parse = TRUE, na.rm = TRUE)+
-        ggplot2::geom_text(ggplot2::aes(x = x, y = y, label = text, colour = color),
-                           size = text_size + text_size/70, data = upper_DM_text, parse = TRUE, na.rm = TRUE)
-    }
-
+      ggtext::geom_richtext(ggplot2::aes(x = x, y = y, label = text, colour = color),
+                         size = text_size, data = upper_DM_text, fill = NA, label.color = NA,
+                         label.padding = grid::unit(rep(0, 4), "pt"), na.rm = TRUE)
   }
 
   ### draw the color bar
